#include <stdio.h>
#include <stdlib.h>
void warte()
{
        char b[2];
	void *ptr;
        fprintf(stderr,"...Please press <Enter> to read on...");
       	ptr=fgets(b,sizeof(b),stdin);
	if (ptr==NULL) fprintf(stderr,"\n");
}

void print_gpl()
{
	// this is a simple lz-coded version of the gpl.
	// i had a little fun with this.
const unsigned short packbits=62833;
const unsigned char packedgpl[7855]={
	0x12,0x03,0x08,0xa8,0xe8,0xc8,0xa9,0x5a,0x4a,0x91,0x53,0x91,0x54,0x10,0x13,0x08,
	0x54,0x95,0x10,0x53,0xd2,0x10,0xe8,0xd4,0xb2,0x4c,0x15,0x29,0x1a,0x70,0x48,0x56,
	0x65,0x72,0x73,0x69,0x6f,0x6e,0x20,0x32,0x2c,0x20,0x4a,0x75,0x6e,0x65,0x20,0x31,
	0x39,0x39,0x31,0x0a,0x0a,0x20,0x43,0x6f,0x70,0x79,0x72,0x69,0x67,0x68,0x74,0x20,
	0x28,0x43,0xa9,0x93,0x83,0x93,0x2b,0xb3,0xa4,0x03,0x62,0x24,0x57,0x2e,0x38,0x53,
	0x6f,0x66,0x74,0x77,0xe1,0xb2,0x2d,0x59,0xef,0x62,0x43,0x16,0x46,0x3f,0xae,0x32,
	0x95,0xe4,0x36,0xe6,0x2a,0xbf,0x37,0x8a,0x79,0x4f,0x50,0x4d,0x0e,0x08,0x55,0x59,
	0x1b,0x1c,0xbb,0x98,0x81,0x62,0x0b,0x1b,0x2b,0x17,0x39,0x53,0x75,0x69,0xf4,0x82,
	0x69,0x66,0x06,0x56,0x3e,0x09,0xbd,0xcd,0xd1,0x13,0x9c,0xa6,0x60,0x71,0x04,0x23,
	0x13,0x13,0x13,0xd3,0x12,0x2b,0xa8,0x6e,0xc5,0x56,0xd5,0x54,0xb0,0xe0,0x29,0xb2,
	0x97,0x15,0xf9,0x02,0x5b,0x4a,0xa5,0xcd,0x81,0xc0,0xcb,0xb2,0x76,0x19,0x2d,0xa4,
	0xc8,0x40,0xe5,0x15,0xc8,0xf8,0x08,0x01,0x09,0x97,0x35,0x20,0xe4,0x22,0x8d,0x5e,
	0x8a,0x88,0xd5,0x0f,0xe9,0x51,0x26,0x3e,0x6d,0xda,0x29,0x5c,0x5a,0xd9,0x9c,0x02,
	0xc8,0x9b,0x19,0x08,0x1d,0xfa,0x48,0xc3,0x96,0x36,0x56,0xe6,0x36,0x57,0x06,0x42,
	0xf6,0x36,0x56,0xd7,0x56,0xe6,0x46,0xc7,0x02,0x3a,0xf1,0x80,0x8c,0xa1,0x85,0xb9,
	0x9d,0xa5,0xb9,0x9d,0x81,0xa4,0xd1,0x53,0x34,0x6e,0x6f,0x74,0x20,0x61,0x6c,0x6c,
	0x6f,0x77,0x65,0x64,0x2e,0x8a,0x03,0x62,0x89,0x00,0x25,0x57,0x16,0xd6,0x26,0xc6,
	0x56,0x3e,0x3e,0x80,0x50,0xa1,0x95,0xa3,0x43,0x73,0x20,0x66,0x6f,0x72,0x20,0xed,
	0xd3,0x0a,0xc8,0x3c,0x82,0x49,0x70,0x91,0x95,0xcd,0xa5,0x9d,0xb9,0x1b,0x37,0x74,
	0x61,0xeb,0x23,0xd7,0x5d,0x58,0x1e,0x48,0xde,0x5b,0x9d,0x9c,0x82,0xf9,0x6c,0x41,
	0xf6,0xd6,0x4e,0x80,0xcd,0xa1,0x17,0xdc,0x83,0x6e,0x95,0x3c,0xd0,0xd0,0xb9,0x80,
	0x80,0x08,0xe5,0x8f,0x3f,0x6e,0x74,0x72,0x61,0xf3,0xe3,0x11,0xfd,0x58,0x5d,0x06,
	0x94,0xb9,0x95,0xc9,0x85,0xb1,0x81,0x40,0xd5,0x89,0x4f,0x56,0x0a,0xcc,0x07,0xf1,
	0xc4,0x94,0xe6,0x46,0x57,0xe6,0x46,0x6e,0x7e,0x9d,0xd5,0x85,0xc9,0x85,0x0f,0x79,
	0xe5,0xd5,0x18,0xe8,0x4f,0xde,0xa2,0x25,0xff,0x28,0xe2,0x5a,0x5a,0x5a,0xc7,0x40,
	0xed,0x54,0x98,0xb9,0xfa,0x61,0x30,0x05,0x37,0xd7,0x3a,0xe0,0x25,0x0d,0x57,0x58,
	0x07,0xa7,0xe3,0x9a,0x39,0x90,0xba,0xf9,0x59,0xe1,0xc4,0x86,0x7a,0x16,0xa2,0xe8,
	0xc9,0x01,0x45,0xec,0x84,0xc1,0xc1,0xb1,0x8f,0x40,0xa9,0xc0,0x65,0xd6,0x3a,0xe8,
	0x98,0x91,0xb7,0xa0,0xa8,0x68,0x38,0x99,0x5f,0xb5,0x0e,0x84,0x67,0x50,0x61,0x6e,
	0x79,0x20,0xef,0xe3,0x28,0x39,0x10,0x38,0xb9,0xb7,0x33,0xb9,0xb0,0x36,0x90,0x3b,
	0xb4,0x77,0xc2,0x53,0x1d,0x1d,0xda,0x9b,0xdc,0xfc,0xd8,0xa6,0x7d,0xb0,0x39,0xb9,
	0x52,0xa8,0x9b,0x37,0x95,0x0e,0x97,0x50,0xa6,0xde,0xda,0xca,0x0f,0xd8,0xaf,0xc5,
	0x0c,0x75,0xe7,0x68,0xec,0x7d,0xec,0x39,0xe9,0x11,0xcb,0x53,0xc4,0xe0,0x30,0xa5,
	0x89,0xc9,0x85,0xc9,0xe5,0x3f,0x72,0x53,0x4e,0x69,0x6e,0x73,0x74,0x65,0x61,0x64,
	0x2e,0x29,0x20,0x20,0x59,0x6f,0x75,0x20,0x63,0x61,0xee,0xa5,0xa7,0x7c,0x6a,0xe9,
	0x90,0xbb,0xf2,0x7b,0xc7,0x9a,0x9f,0xdf,0xbc,0xbd,0xcf,0x4f,0x40,0x40,0xae,0xd0,
	0xca,0xdc,0x40,0xee,0x07,0x47,0x70,0x65,0x61,0xeb,0xa4,0xe8,0x32,0x32,0x5e,0x8c,
	0x95,0x1e,0x4f,0x1c,0x93,0x2b,0x33,0x2b,0x93,0x93,0xa7,0x74,0x8f,0xae,0xcf,0x3f,
	0xac,0x34,0x13,0x05,0x38,0xf9,0x71,0xfa,0xbc,0xeb,0x79,0xec,0xfe,0x3e,0xbf,0xa6,
	0xcd,0xff,0x5c,0x5d,0x45,0x61,0xf4,0x84,0x1f,0x0a,0x68,0x61,0xf6,0x46,0xa3,0xeb,
	0x9f,0xbb,0x8e,0xf6,0x8f,0x8f,0xb9,0x73,0x40,0xa8,0xf7,0x20,0xf2,0x74,0x21,0x6f,
	0xf2,0xd3,0xb2,0x03,0xb2,0x83,0x25,0xf6,0x83,0x3e,0x20,0x69,0xe6,0xe4,0x40,0x20,
	0x77,0x69,0x73,0x68,0xa9,0xf4,0x9b,0xc6,0xc0,0x13,0x3b,0x63,0x65,0xe9,0x53,0x41,
	0xf3,0x53,0xb7,0x43,0x46,0x63,0x6f,0xe4,0x63,0x2f,0xf2,0x35,0x36,0x67,0xe5,0xf3,
	0x12,0x74,0x8a,0x78,0xc6,0x33,0x9f,0xc3,0xc9,0x3b,0xc7,0x54,0xc9,0x37,0xa1,0x6d,
	0xa3,0x23,0xc9,0x73,0x25,0xa0,0x43,0x43,0xe3,0x66,0xc3,0xd4,0x49,0x6e,0x20,0x6e,
	0x65,0xf7,0xb6,0xc3,0x98,0x37,0xbb,0x56,0xab,0x18,0x4b,0x6b,0x6e,0x6f,0xf7,0x49,
	0x4b,0xe4,0x23,0x18,0x68,0xe5,0x53,0xcd,0xa3,0x45,0x6e,0x67,0xf3,0x65,0x38,0x54,
	0xef,0x04,0x4f,0x74,0x65,0xe3,0x25,0x50,0x72,0xa0,0x55,0x84,0x03,0xb8,0xb3,0x3a,
	0xee,0xe3,0xc1,0xc9,0x3f,0x72,0xe5,0x94,0x42,0xe3,0x24,0xb1,0x13,0xa8,0x04,0xd0,
	0x63,0x45,0x62,0x69,0x64,0x8a,0xd3,0xab,0xe4,0x8c,0x44,0x42,0xe5,0xe3,0xab,0xd4,
	0xd0,0x86,0xd1,0x96,0xd3,0x04,0xcd,0xa4,0x2b,0x73,0xeb,0x86,0xd7,0x73,0x20,0x75,
	0x72,0xf2,0x64,0x9e,0xb3,0xd8,0x53,0xcc,0x36,0x58,0x2e,0x8a,0x53,0x95,0x04,0xd8,
	0x2d,0xd5,0x23,0x1f,0x73,0x6c,0xe1,0xf3,0xc2,0xf4,0x0d,0x65,0x72,0x74,0xe1,0x53,
	0xce,0x73,0x5b,0xf0,0x03,0x5c,0x69,0x62,0x69,0x6c,0x69,0xf4,0x54,0xc3,0xb4,0xa4,
	0x44,0xd9,0x06,0x4a,0x8a,0x7f,0xc2,0xc6,0xcd,0x4c,0x4c,0xac,0x94,0xd8,0x07,0x4a,
	0x6d,0x6f,0x64,0x69,0xe6,0xc4,0xb6,0x45,0x52,0xc6,0xc3,0x61,0x65,0x78,0xe1,0x54,
	0x09,0xac,0xe8,0xe1,0x9f,0xdf,0x86,0x60,0x73,0x75,0x63,0x68,0x20,0xe1,0x08,0xcf,
	0xf3,0x53,0x68,0xe5,0x94,0x2f,0x8a,0x73,0x66,0xf4,0xc3,0xc5,0x53,0xe3,0xb5,0x24,
	0x20,0x66,0xe5,0xe3,0xe3,0x25,0x62,0xf5,0x83,0x28,0xe7,0x24,0xc8,0x55,0x5a,0x65,
	0x63,0xe9,0x53,0x65,0xee,0x73,0xd8,0xf4,0xa4,0x5a,0xda,0xd5,0xd5,0x34,0x37,0xa0,
	0x34,0xc1,0x13,0xbd,0x04,0xb6,0xe5,0xe8,0x0f,0xc0,0xb3,0x6a,0xf9,0x15,0x38,0xac,
	0xd9,0xc7,0x2b,0xc9,0xe3,0xed,0xe3,0xa1,0x89,0xc8,0x33,0x6c,0xc1,0xc3,0xcf,0xa9,
	0x68,0x73,0xe8,0xa3,0xd0,0xc3,0xef,0x23,0xc2,0x96,0xd1,0x63,0x8d,0xb4,0xaa,0xd5,
	0xed,0x76,0xd0,0x43,0x73,0x69,0x72,0x8a,0x98,0xda,0x84,0xb8,0xf5,0xce,0xff,0x52,
	0xf3,0xd3,0x46,0x74,0x68,0x20,0x74,0xf7,0x93,0x59,0x74,0x65,0x70,0x73,0x3a,0x20,
	0x28,0x31,0xa9,0x15,0x8e,0x56,0x84,0xee,0xe0,0xb3,0x4f,0x0a,0x28,0x32,0xa9,0x93,
	0xe5,0x43,0xbb,0x87,0xd7,0xcb,0x10,0x77,0x68,0xe9,0xf3,0xe5,0x34,0x69,0xf3,0xf5,
	0x79,0x6c,0x65,0xe7,0xd3,0xbd,0x55,0x0d,0xf3,0xd5,0x82,0xf7,0x0d,0xac,0x8c,0xdf,
	0x23,0x79,0xaf,0x35,0x96,0x85,0xe2,0x4c,0xf8,0xa5,0x74,0x41,0x6c,0xf3,0x63,0x6e,
	0xe9,0xcf,0x94,0x85,0xd3,0x97,0x2d,0x6b,0x39,0xaa,0xf2,0xa4,0x2e,0x39,0x5f,0xda,
	0xa7,0xb3,0x75,0xcd,0xa7,0xd6,0x29,0xc5,0xa4,0x7a,0xd1,0x75,0xb2,0xe8,0x6c,0x9b,
	0x72,0x54,0x86,0xe3,0x30,0x27,0x4b,0xd0,0x0f,0x0a,0x3e,0xae,0x4a,0x70,0xb6,0x3c,
	0x86,0xdb,0xfb,0xd0,0x20,0x79,0x92,0x0f,0xf9,0xa5,0x80,0x8b,0xf4,0xb6,0x86,0x9c,
	0x85,0x93,0xec,0x0c,0x96,0xdc,0x70,0xb5,0x9f,0xf4,0x42,0x99,0xd3,0x89,0xda,0xca,
	0x89,0x0a,0x95,0xb1,0x93,0xb4,0x9c,0x14,0x04,0x17,0x36,0x37,0x3f,0xb0,0x98,0x60,
	0xc1,0x5d,0x99,0xe2,0x9d,0x92,0x79,0xde,0xb4,0xa3,0x83,0x2f,0xe7,0x8e,0x19,0xba,
	0x47,0x6d,0x5b,0xbe,0x16,0x61,0x22,0x69,0xa2,0xf7,0xf1,0x3b,0x69,0x6e,0x61,0x6c,
	0xac,0x53,0x8b,0x2d,0x09,0x53,0xaf,0x9c,0x0e,0x3c,0x4e,0x71,0x5c,0xee,0x8c,0x07,
	0xb9,0x37,0xb2,0xba,0x71,0x83,0xc5,0x85,0x2f,0x89,0xec,0x0e,0xaa,0x25,0x84,0x3c,
	0xb2,0x83,0x9d,0xac,0x2e,0x3d,0xdf,0x6d,0x48,0x8a,0x57,0x2d,0x4e,0x87,0x29,0xc1,
	0xd5,0xd1,0x57,0xc4,0xb4,0xa4,0x63,0x4c,0x60,0x89,0x7d,0xc2,0x2d,0x89,0x64,0x66,
	0xa7,0x44,0x90,0xe8,0xd0,0x47,0x29,0x4e,0x79,0x9c,0x9b,0x3c,0xb7,0x91,0xba,0x10,
	0xfd,0xac,0xcd,0x9a,0xc5,0x97,0x29,0xe0,0xe9,0x33,0x0f,0xd2,0xad,0xa6,0x4b,0x6e,
	0xb4,0x18,0x8b,0xdd,0x5b,0x3a,0xf5,0xd3,0x91,0x9f,0xf4,0x4b,0x09,0x10,0xcf,0x47,
	0x9e,0x93,0x89,0xdc,0x97,0xb2,0xe5,0x68,0xd9,0x19,0xb4,0x84,0x88,0xf3,0x58,0x52,
	0x51,0x4a,0x73,0x23,0x4b,0xb3,0x4b,0x23,0xab,0xa7,0xc0,0x04,0xf2,0x26,0x5e,0xd4,
	0xd5,0x7a,0x73,0x62,0xc5,0xf9,0x31,0x6e,0x20,0xe5,0xb3,0x79,0x47,0x2a,0x4f,0x0f,
	0x2e,0xdc,0x39,0xfd,0x16,0x03,0xf4,0x20,0xe9,0x61,0x1e,0x65,0xf4,0xa3,0x33,0x89,
	0x4b,0x92,0x4a,0x9d,0x27,0x4c,0x37,0x78,0x06,0x71,0xc1,0xe0,0x02,0x48,0x6d,0xe1,
	0xf3,0x48,0xc7,0x6d,0x8c,0xb1,0x95,0x85,0x5f,0x78,0x9e,0xc3,0x7c,0xbc,0xd9,0x2a,
	0x8e,0x78,0x5e,0x05,0x72,0x53,0xc0,0x07,0x85,0x47,0x03,0xd7,0x62,0x26,0x6a,0x3a,
	0xa7,0x9a,0x92,0x72,0x76,0x6a,0x3a,0x54,0x6c,0xec,0x46,0x52,0x27,0x3b,0x4f,0x98,
	0x1a,0x4b,0x4f,0x94,0x5b,0x4b,0xe4,0x7d,0x1e,0xb4,0xf9,0x56,0x32,0xd5,0x54,0x7d,
	0x07,0x48,0xb1,0xea,0x91,0x3d,0x12,0xa4,0x68,0xaa,0x68,0xdc,0x22,0x86,0xd9,0x3b,
	0xe5,0x04,0xd7,0x03,0x81,0x6f,0x00,0xb9,0x02,0x0e,0xcc,0xa2,0x2a,0x92,0x6a,0x9a,
	0x02,0x09,0x72,0x22,0x02,0x19,0x7a,0x72,0x22,0x4a,0xa2,0x4a,0x7a,0x72,0x9a,0x02,
	0x31,0x7a,0x92,0x1e,0xad,0x05,0x95,0x95,0xe4,0x74,0xc4,0x02,0x42,0x94,0x34,0x45,
	0x25,0x95,0x24,0x54,0x4d,0x60,0xbb,0xac,0x56,0xd3,0x13,0x51,0x92,0x51,0xd2,0x50,
	0x30,0xed,0x6d,0xaa,0x56,0x30,0xae,0xe5,0x25,0x5f,0x4e,0xd6,0x39,0x3e,0x91,0x5c,
	0x4b,0x7a,0xf6,0xb5,0xe1,0x8b,0xbb,0x37,0xb9,0xf5,0x83,0xbd,0x74,0x1b,0xc7,0x43,
	0xcd,0x29,0x84,0x13,0xb0,0xa6,0x31,0x02,0x4f,0x9b,0xb0,0x70,0x32,0x61,0x67,0xd5,
	0x3b,0x68,0x6f,0xec,0x14,0x5a,0xe6,0xc2,0x29,0x60,0xd3,0x9e,0x6a,0x9f,0xc5,0x38,
	0x9a,0x5a,0xb7,0x0f,0x99,0x62,0x61,0xe1,0x52,0xdf,0x56,0xae,0xf1,0x20,0x3e,0xf6,
	0x3c,0xce,0x5d,0x5c,0xa2,0x0c,0x44,0x04,0xda,0x68,0x97,0xe8,0x7c,0x84,0xf2,0x41,
	0x59,0x2c,0x8a,0x25,0x3b,0x53,0x75,0x57,0x97,0xdd,0xd9,0x4d,0xc4,0xbb,0x20,0xef,
	0xe4,0x27,0xd1,0x22,0x5e,0x62,0xe1,0xa6,0x8c,0x4b,0x84,0xe3,0x14,0x53,0x68,0x2b,
	0x1f,0xe3,0x02,0x52,0x3e,0x67,0xf7,0x40,0xf8,0x85,0x72,0xf2,0xe3,0xe4,0xc6,0xe7,
	0x83,0xa5,0xd9,0xcf,0xc7,0x1e,0x3a,0x5d,0x8f,0xdc,0x3a,0xb8,0xbe,0x2f,0xb6,0xb0,
	0x3b,0x5d,0xe3,0xc8,0x84,0x99,0xa7,0xed,0x84,0x13,0x61,0x36,0x6a,0x7e,0xcf,0xfb,
	0x80,0x74,0xeb,0x32,0x10,0xb8,0x37,0xf9,0x02,0xd9,0xf5,0x4d,0x58,0x14,0x0f,0x96,
	0xa7,0x3d,0xa4,0x3f,0x4e,0x67,0x97,0x31,0x76,0xa5,0x6b,0x4a,0xbf,0x49,0x5c,0xc8,
	0xc9,0x25,0x13,0x1b,0x2f,0xdf,0xa5,0xc0,0x3e,0xdd,0xa9,0x2e,0xec,0x9c,0x94,0x18,
	0x0a,0xf2,0xac,0xe1,0xf9,0x4b,0xe6,0x73,0xc2,0x47,0xdc,0xde,0x57,0x27,0x93,0x5e,
	0xe0,0x61,0x8c,0xad,0x9e,0xd0,0x23,0x11,0xb5,0xf7,0x11,0x09,0x6c,0xe9,0x03,0x2e,
	0xaf,0xb2,0x13,0x12,0xb6,0x12,0x06,0x22,0xca,0x49,0x4d,0x94,0xb8,0x46,0x31,0x41,
	0xe0,0x2b,0xd6,0x35,0x90,0xc2,0xc8,0xc8,0x27,0xbb,0x96,0xb2,0x9a,0x03,0x11,0x9d,
	0xde,0x23,0x3a,0xd4,0x2a,0x78,0x44,0x90,0xbd,0x91,0x57,0xf3,0xdd,0xf3,0xce,0x67,
	0x97,0xfe,0xbf,0x4e,0x87,0xdd,0x48,0xbd,0xde,0x27,0x21,0x4f,0x1d,0x99,0xf6,0xc2,
	0x8f,0x88,0xed,0x9a,0x3e,0xae,0x66,0x52,0x47,0x37,0x97,0x5e,0x79,0x7a,0x5e,0xee,
	0x50,0x78,0x54,0x62,0xe1,0x24,0x95,0xcc,0x14,0xe4,0xea,0xdc,0x9f,0xa1,0x97,0x65,
	0xb6,0xa4,0x6c,0xb9,0xa5,0x8c,0xdc,0x0c,0x79,0x61,0xa5,0x3a,0xfa,0x81,0xcb,0x43,
	0xab,0x29,0x84,0x6a,0xa3,0x53,0x5c,0x90,0xf1,0xe6,0x4e,0x6b,0x93,0x56,0x3a,0x31,
	0x7b,0x22,0x8f,0xf6,0xed,0xe6,0xe8,0xd2,0xe8,0x4b,0xfc,0x1a,0x40,0x67,0x4a,0xa6,
	0x88,0x90,0x0e,0x75,0x1c,0x54,0x19,0x3c,0x7d,0xd6,0x91,0xd4,0xa3,0xd2,0x47,0x4e,
	0x13,0xa2,0x13,0x2b,0x9f,0xc6,0x59,0x77,0x7a,0x96,0xfc,0x13,0x7a,0x6a,0x78,0x29,
	0x2e,0x8a,0xb3,0x38,0x51,0xc1,0x9b,0x3c,0x93,0xab,0x27,0xf9,0x49,0x17,0x7f,0x0e,
	0xfc,0x38,0xce,0xbb,0xc7,0xf9,0xe8,0xc8,0xde,0xca,0x0d,0x2f,0xc5,0xb8,0x5a,0xb1,
	0x9d,0x05,0xfe,0xe2,0xf0,0xe3,0x61,0x17,0xd8,0xab,0x7b,0x27,0xf3,0xfc,0x6f,0x49,
	0xbe,0xb3,0x1e,0x25,0x56,0x3a,0x33,0x9a,0x8c,0x59,0xfb,0xa4,0xa7,0xfa,0x51,0xb3,
	0x73,0xc7,0x47,0x42,0x93,0x51,0xc5,0x05,0x4a,0xeb,0x0e,0x5c,0xda,0x58,0xdd,0x5b,
	0xdd,0xfc,0x60,0xbb,0x85,0xc8,0xc0,0x1b,0x94,0x3a,0x64,0xed,0x44,0x40,0xf0,0xe4,
	0xc3,0x0e,0x73,0x3a,0x69,0x6f,0x3d,0xa0,0x17,0xf9,0xf2,0x05,0x3c,0x05,0x30,0x8a,
	0xb3,0xa7,0xbd,0x9e,0xe5,0x33,0xc6,0x16,0x96,0xd6,0x3e,0x51,0xef,0xd4,0xbe,0x58,
	0x87,0xec,0x80,0xac,0x95,0x95,0xc1,0x13,0x5a,0x4b,0x7d,0xee,0x9d,0x1a,0x8a,0x46,
	0x05,0x9f,0x18,0x5a,0x64,0x6c,0x01,0x86,0x8d,0xb9,0xda,0xad,0x48,0xb8,0x4f,0x98,
	0xd8,0x5c,0x99,0xfb,0x60,0xc1,0x74,0x9f,0x4e,0xfa,0x9b,0x6d,0xf0,0xa4,0x15,0xe4,
	0x26,0x69,0x6a,0xaf,0xb8,0xde,0xa8,0xd7,0xbe,0x53,0xef,0x96,0x0d,0x8c,0x2d,0xec,
	0x99,0x42,0x0a,0x61,0x6c,0xef,0xb3,0xf3,0x9a,0xd9,0xa9,0xf4,0xf0,0x04,0xbe,0x99,
	0xf8,0x1a,0x14,0x59,0x83,0xe6,0xf5,0xa1,0xf3,0xbd,0xa0,0xe5,0xcd,0xcf,0x8c,0xc3,
	0x7e,0x7c,0xae,0x39,0xb6,0x48,0x3b,0xda,0x3f,0x6c,0x90,0x67,0x49,0x9c,0x43,0x13,
	0xdb,0xff,0x3b,0x68,0x10,0xfc,0x95,0xb4,0xa4,0x09,0x67,0x1d,0xba,0x1d,0x28,0xcd,
	0x28,0xf8,0x38,0x21,0x22,0xa0,0x59,0x81,0x8f,0xac,0x1e,0xbe,0xd7,0x7e,0x16,0x60,
	0x6c,0x01,0x71,0x55,0xc7,0x1f,0xfb,0xee,0x2f,0x7b,0x22,0x8d,0xa2,0xa9,0xb4,0x83,
	0x1e,0xd5,0x17,0xbe,0xd2,0x6e,0x65,0xf1,0xe3,0xbb,0xaa,0x1e,0x5b,0xaa,0x8b,0x91,
	0x2f,0x6b,0x9f,0x25,0xc7,0x7a,0x52,0x7b,0x7f,0xec,0x65,0xb3,0x3d,0xc2,0x4c,0xdf,
	0x67,0x14,0xa3,0x10,0x26,0x3e,0xcf,0xee,0xcb,0xbf,0x45,0xfd,0x84,0x8f,0x01,0x3a,
	0xeb,0xef,0xe4,0x9b,0x34,0x08,0x9b,0x79,0x3c,0xab,0xb0,0xbe,0x2b,0xba,0xc4,0x1b,
	0x81,0x80,0x84,0xa5,0x6a,0xb1,0x31,0x16,0x4e,0xba,0x2a,0xb9,0xc9,0xa9,0x8a,0x98,
	0xa5,0xb1,0x5b,0xea,0x32,0x3e,0x93,0x71,0x65,0xc6,0x33,0x21,0xd3,0xc6,0x7b,0x8b,
	0x70,0x05,0xcb,0x93,0x9a,0xd0,0x9b,0xce,0x8b,0xb2,0x64,0xb1,0xc6,0xd6,0xea,0x5a,
	0xb9,0x8c,0xab,0xee,0x40,0x8c,0xf9,0x0b,0xdb,0xc6,0x5c,0xbb,0x11,0x08,0x88,0xf8,
	0x1f,0xcb,0x96,0x0d,0xd7,0x98,0x9c,0x12,0xf3,0x0a,0xc9,0x03,0x26,0x9f,0x09,0x7c,
	0xae,0xe4,0xe8,0xb6,0xa4,0x34,0xcf,0xb3,0x38,0x97,0x20,0x71,0x98,0x04,0xa2,0xc8,
	0x0f,0xd6,0x7c,0xd0,0x6b,0x69,0x4e,0xf3,0x96,0xcc,0x92,0xb8,0xfc,0xbb,0xee,0xd1,
	0xc7,0x05,0x39,0x57,0xe8,0x5c,0x69,0xc8,0x9b,0x39,0x89,0x9b,0x9d,0xa9,0x8e,0xf4,
	0x3b,0x18,0x72,0x59,0xce,0xb3,0x38,0x8f,0x1c,0x7a,0x37,0x31,0xad,0xb5,0x45,0x08,
	0xa5,0xc9,0x91,0x27,0xf5,0x4c,0xe2,0xf1,0xa3,0xc9,0x5f,0x10,0xa3,0xd1,0x34,0x96,
	0x8a,0x96,0x68,0x72,0xcb,0x78,0xc7,0xb8,0x4f,0x84,0x5c,0x16,0xea,0x74,0xa6,0x63,
	0xf6,0x52,0xb7,0x58,0x5f,0x28,0x8d,0x07,0xf2,0x53,0x15,0x0f,0xee,0xc4,0x6e,0xd3,
	0xf3,0xb4,0x99,0x73,0x5d,0xd4,0xcf,0x33,0x9a,0x12,0xa7,0x69,0xcd,0x74,0x20,0x97,
	0x24,0x3d,0x0a,0x93,0x3c,0x95,0xb5,0x68,0xf3,0x92,0x6c,0x4c,0x4d,0x72,0x35,0xd2,
	0x0b,0x48,0x57,0xae,0x3a,0x9e,0xb3,0x4d,0xd1,0x84,0x28,0xc8,0x91,0x8f,0x61,0x3b,
	0xf1,0xf2,0x28,0x86,0x55,0x3e,0xcf,0x10,0x4c,0x1c,0x8f,0x3c,0xc5,0xcd,0x13,0xbe,
	0x12,0x8f,0x6c,0xc1,0x92,0x9b,0xfb,0x34,0x0c,0x63,0xe5,0xb4,0x11,0x5e,0x67,0x5b,
	0x14,0x72,0xf3,0xc0,0xfb,0xcd,0x2e,0x15,0x14,0x5e,0x11,0xf5,0x19,0xd5,0x4f,0x86,
	0xee,0x1c,0x82,0x4a,0xa7,0xea,0xfc,0xa2,0x83,0x91,0x5a,0x00,0x9b,0x69,0xf3,0x31,
	0xca,0x16,0x51,0xa7,0x5b,0x95,0xaa,0xfa,0x64,0x5d,0x89,0x65,0x1c,0x2f,0x7a,0x6a,
	0xd6,0x32,0x82,0xd1,0x75,0x42,0x57,0x66,0xfd,0xaf,0xf2,0xb0,0xa9,0xa5,0x5a,0x95,
	0xb1,0xb1,0xa3,0xce,0x4b,0xb3,0xf5,0xe0,0xaf,0xf3,0x8e,0xbc,0x81,0xd8,0xa5,0x4f,
	0x3a,0xe9,0xff,0x70,0x6d,0xd7,0x4a,0xc4,0xa0,0x14,0xe1,0x8d,0x95,0x97,0x61,0xa4,
	0x4b,0xda,0x6e,0x33,0x3a,0x74,0x73,0x65,0xec,0x53,0x20,0xb7,0x1f,0x4d,0x20,0x61,
	0x85,0xd8,0xd4,0xf7,0x96,0xa6,0x9b,0x68,0xb4,0xf9,0xd3,0xd6,0x65,0x92,0xf9,0xab,
	0x18,0x75,0x69,0xd2,0x17,0x26,0xe3,0x87,0x8c,0xdb,0xf5,0x3f,0xba,0xc3,0x5b,0xc5,
	0xd5,0xa5,0x93,0xb4,0x9b,0xfb,0xf4,0x1b,0x5a,0x2e,0xa9,0x09,0x5b,0xd6,0xb0,0x4d,
	0xde,0xf6,0xdc,0xcf,0x95,0x36,0x9e,0x2c,0x9c,0x57,0x74,0x71,0xda,0x6a,0x3f,0x17,
	0x25,0xa2,0x38,0x96,0x95,0x1b,0xfd,0x20,0x5c,0xe1,0x93,0x92,0x8e,0x17,0x79,0xbd,
	0x65,0x69,0xd8,0x34,0x8f,0xd6,0xc3,0x6d,0x3c,0xee,0xd3,0xce,0x9b,0x22,0x57,0x34,
	0x4c,0xf4,0xe6,0xa8,0xcf,0x13,0x47,0xcd,0xbd,0xb9,0xcf,0xca,0x5d,0xb5,0x21,0xa1,
	0xb9,0x64,0x6c,0xf3,0xc4,0x4b,0x68,0xd7,0x5c,0xf9,0x7c,0xd0,0x84,0x53,0x53,0xd0,
	0x4d,0x53,0x36,0xf1,0x36,0xed,0xd3,0x64,0x4f,0xee,0x59,0xbf,0x21,0x89,0xd3,0xca,
	0x43,0x1b,0x7c,0x4d,0xde,0x6e,0xc5,0xd0,0xb3,0xe1,0xbc,0xdb,0x4c,0xa8,0xf9,0xf6,
	0x44,0x0b,0x8a,0x09,0x73,0xd7,0x2b,0xfd,0x6e,0x73,0x81,0x9c,0x33,0x71,0x7b,0xe6,
	0x4d,0xb1,0xe1,0xdc,0xba,0x88,0x7f,0x73,0x90,0x5c,0x9a,0x48,0xf8,0xd4,0x8b,0xf9,
	0x7e,0x4f,0x04,0x5e,0xd9,0x73,0xdd,0xa7,0xb6,0x3f,0x5b,0xf2,0x4a,0xe6,0xed,0x6e,
	0x5a,0x8a,0x5f,0x22,0x1b,0xcc,0xcc,0x1e,0xee,0x99,0xc7,0xc6,0x85,0x63,0xa5,0x7a,
	0x78,0x38,0xc6,0xd0,0x96,0x45,0x66,0xf0,0x6d,0xcf,0xa2,0x1e,0x9f,0x86,0xaf,0xda,
	0x37,0x8c,0xdd,0xed,0xb8,0x32,0xf8,0x54,0x1e,0x5e,0xbf,0xa5,0x48,0x25,0xf7,0x1c,
	0xdd,0x05,0x8a,0x63,0xaa,0x3b,0x0d,0xf2,0xe4,0xe3,0xf6,0x80,0xce,0x43,0x5e,0xaa,
	0xaa,0x45,0x61,0xf2,0x23,0x7c,0xc8,0x91,0x4f,0xca,0x5c,0x37,0xf7,0x1c,0x64,0x20,
	0xf7,0xc4,0x19,0x1b,0x8b,0x41,0x3d,0x13,0xf9,0x8c,0xbf,0xf9,0x12,0x52,0x2c,0x5e,
	0xe3,0xe1,0x25,0x8a,0xc5,0x45,0x5a,0x9f,0x4c,0xeb,0x32,0x8d,0xc1,0x2b,0x58,0x96,
	0xb8,0x33,0x5f,0xb9,0x66,0x76,0x9d,0x63,0x97,0x1b,0xf1,0x22,0x4f,0xd9,0xe0,0x9c,
	0xc6,0x15,0x90,0x9b,0x6b,0x3a,0x91,0xd9,0x0e,0xe8,0x60,0xe0,0x43,0x8e,0x9b,0x21,
	0x7e,0x5f,0x79,0xd1,0x33,0x0a,0x65,0x78,0x65,0xf2,0x06,0xae,0x22,0xab,0x69,0xd1,
	0x27,0xc1,0xa4,0x96,0x6a,0x3e,0x23,0xce,0xc9,0xec,0x5c,0x11,0xe3,0x63,0xb2,0xd2,
	0x5b,0x7e,0xd2,0xcc,0xfc,0x7b,0xc8,0x69,0x12,0x25,0x0f,0xb5,0x45,0x6e,0xe9,0x15,
	0xeb,0x88,0xca,0x34,0x2b,0x9c,0x9d,0x93,0x4b,0x8e,0x01,0xfa,0xb9,0xb5,0xf6,0x99,
	0xd3,0x55,0xfe,0x28,0xba,0x15,0xbb,0xcf,0x11,0x0f,0xc4,0x8b,0x41,0xed,0x63,0xc8,
	0xdd,0xf3,0x12,0xab,0x16,0x06,0x62,0xf7,0xc6,0x3e,0x1a,0x21,0xe9,0x62,0xe1,0x33,
	0x4b,0xbd,0xc9,0xcf,0x5e,0x7b,0x03,0xb5,0xf2,0xe7,0xc6,0xfe,0x2a,0x9a,0x25,0x6e,
	0xb7,0x23,0xc1,0xba,0x3a,0xa6,0x9b,0x75,0x5d,0x3d,0x38,0xc9,0xb9,0x6f,0x43,0x5b,
	0x11,0x35,0xfb,0x87,0xef,0x5b,0xbe,0xbf,0xa8,0xff,0xa7,0x3e,0xa4,0xf1,0xb8,0xb4,
	0x76,0x42,0xe3,0x9e,0x3c,0x97,0xe7,0x84,0x53,0x6f,0x62,0xea,0x94,0xa3,0x62,0x23,
	0x39,0xd7,0xd9,0xf8,0xc4,0xa5,0xc4,0x72,0x13,0x84,0xfc,0x26,0x74,0xe5,0xe2,0x87,
	0xb7,0xcd,0x81,0xc4,0x96,0xcf,0x26,0x3b,0xb8,0xf0,0x1c,0xca,0xbf,0x28,0xa7,0xa6,
	0x3c,0xd9,0x37,0xe9,0xa2,0x97,0x89,0x5b,0xc9,0x3a,0xf8,0xba,0xfe,0x4a,0x41,0xe3,
	0x73,0x47,0xc1,0x13,0xd8,0x3c,0x51,0x79,0x1a,0xea,0x94,0xc0,0xb1,0x95,0x57,0x4e,
	0x3d,0x9d,0x25,0x6d,0x97,0x85,0x52,0xb5,0xcf,0x46,0x3e,0xf8,0x52,0x2b,0xc5,0xd1,
	0xb4,0xb9,0x5b,0xc1,0xac,0xc7,0x2f,0x29,0xe3,0x44,0x86,0xa3,0x29,0xbe,0x11,0xec,
	0x93,0xee,0x6c,0x27,0x1b,0x88,0xed,0xc1,0x7b,0xf5,0xea,0x67,0xae,0x8d,0x4f,0x17,
	0xf7,0xd6,0x16,0x26,0x97,0x3e,0xb3,0xf9,0x08,0xd8,0x46,0xaa,0xaa,0x27,0x4a,0x56,
	0xb6,0x05,0x4d,0xbb,0x13,0xb9,0xb1,0x26,0xd2,0xfc,0x07,0xbc,0x75,0xea,0x67,0x9a,
	0x17,0x63,0xc4,0x02,0x62,0x17,0xc6,0x3e,0xd5,0x69,0xc9,0xc6,0xd3,0xda,0x0e,0xdd,
	0x4d,0x59,0x39,0xf5,0xa7,0xa4,0xcd,0xe5,0x4f,0xa0,0x5a,0x80,0xa3,0x56,0xc3,0x55,
	0x41,0x17,0x4a,0x3e,0xf8,0xb4,0xc9,0xc6,0x77,0x40,0x0f,0x5b,0xd5,0xf6,0x6e,0xd6,
	0x66,0xb1,0xe0,0xa6,0x5d,0x8d,0xdf,0xa1,0x88,0x4c,0x31,0xe1,0x59,0x65,0xf2,0x08,
	0x21,0x5f,0x12,0xcf,0xd9,0x3a,0xf5,0xb3,0xd8,0xc1,0xd7,0x57,0xff,0x34,0xbc,0xe9,
	0xd4,0xc8,0xbe,0xbb,0x09,0xdf,0x49,0x7c,0x9d,0xcf,0x46,0x66,0x7f,0x19,0xff,0x74,
	0xfc,0xe3,0xee,0x6f,0xc9,0x53,0x29,0x6f,0x5f,0xfd,0xaf,0xf2,0xaf,0xcb,0x7f,0x32,
	0x9f,0x47,0xf4,0x87,0xf3,0x67,0xc1,0xa5,0xb9,0x93,0x5e,0x6f,0x57,0xfa,0x56,0xbf,
	0x45,0x3f,0x9f,0xbf,0x5d,0xfd,0xbc,0xa5,0xda,0x5f,0x42,0x7e,0x71,0xbf,0x03,0x07,
	0x6a,0x5d,0x2e,0x61,0xec,0xe3,0xe4,0xb9,0x9b,0x83,0x7e,0x1f,0xf6,0xe1,0x84,0x56,
	0xed,0xd2,0x8f,0xe7,0xf6,0xe6,0x4e,0x77,0x34,0x65,0xe7,0x23,0x15,0x7f,0x87,0xab,
	0xd4,0x2e,0xb9,0xe0,0x74,0xee,0xe7,0xa2,0xcf,0xca,0xf5,0x0f,0xee,0x2f,0xb9,0x53,
	0xe8,0x5e,0x72,0x7e,0x22,0xd3,0x83,0xd5,0x5f,0x3f,0x4f,0xe5,0xef,0x98,0xf9,0x73,
	0xd3,0x97,0xd8,0x37,0x55,0x3f,0xba,0xb0,0xe9,0x6d,0xe2,0x76,0xe1,0x8f,0xb8,0x4d,
	0xe4,0x76,0x17,0x92,0x16,0xd4,0x17,0xd8,0x6e,0xaa,0xac,0xd1,0xfc,0x35,0x3b,0x1a,
	0x8f,0x3f,0xcc,0xf3,0x69,0xe2,0x64,0xfb,0x93,0x15,0x79,0x3d,0xaa,0x4b,0xc9,0x83,
	0xea,0x57,0xbb,0x48,0x34,0xe6,0xc0,0x7d,0x57,0xea,0x6b,0x82,0xcc,0xec,0xe0,0xda,
	0xe8,0x77,0x2c,0xb4,0xc3,0xfa,0x35,0xdd,0x2f,0x9e,0x1a,0x7f,0xf4,0x5b,0x32,0xe0,
	0x51,0xff,0xd4,0x53,0xca,0x94,0xf8,0x94,0x77,0x3a,0x1d,0x45,0x09,0xfb,0x50,0x64,
	0x29,0x7a,0x3a,0xc8,0x88,0xf7,0x29,0xf8,0x5e,0x59,0x73,0xf0,0xba,0x33,0xbe,0x1c,
	0x04,0x8d,0xf9,0x2c,0x34,0x0d,0x64,0x49,0x28,0xd3,0x13,0x03,0x5b,0xc4,0x46,0x2e,
	0x0d,0xde,0xa8,0x84,0x74,0x8f,0xa5,0x02,0x68,0xc1,0x67,0x09,0x03,0x94,0x7e,0x94,
	0xcd,0x52,0xbe,0x12,0x6a,0x82,0xfd,0x74,0xc1,0x37,0xfd,0xd5,0x03,0xf0,0xf4,0x7f,
	0x90,0xc7,0xdd,0x3b,0x24,0xd9,0xa9,0xec,0xce,0x19,0x48,0x71,0x26,0x87,0x55,0xf0,
	0x9d,0xd4,0xa8,0xd1,0x58,0x8d,0x38,0xcb,0x3b,0x60,0x46,0xef,0x16,0x51,0x91,0xe4,
	0xb5,0xe7,0xd9,0xa4,0xb4,0x62,0x79,0x14,0x73,0xea,0x99,0x72,0x56,0xbe,0x08,0x8f,
	0xc4,0x13,0x5f,0x99,0xb7,0x10,0x1e,0x24,0x90,0x78,0xc1,0x53,0x14,0xc9,0xf9,0x93,
	0xaa,0x71,0x9e,0xb6,0x30,0xf5,0x32,0xcc,0xb4,0x0f,0xaf,0xb7,0xe6,0x2d,0xa8,0x56,
	0x0b,0xa6,0x75,0xd0,0xfa,0x6c,0x7b,0xca,0xe7,0x22,0x59,0x95,0x57,0x3a,0xdf,0x12,
	0xe6,0xb1,0xf6,0xb1,0x73,0xb1,0x25,0x3b,0x23,0x05,0x7b,0xf2,0xe7,0xed,0x38,0xd1,
	0x5f,0x52,0x7b,0x12,0x16,0xd7,0xab,0xc1,0xb4,0x4b,0x9d,0x48,0x50,0x9d,0x7b,0xd1,
	0x64,0xab,0x27,0x9c,0x8b,0x21,0xc5,0x5b,0xb2,0x52,0xdf,0x97,0xd2,0xbc,0x85,0xba,
	0x74,0x6b,0xf0,0xf4,0x68,0xe7,0x40,0xfb,0xfa,0xd9,0xcd,0x0e,0xd3,0x37,0x76,0x89,
	0xbe,0x74,0x8a,0xbc,0x97,0x67,0xcd,0x7d,0x27,0x38,0xa4,0x38,0x07,0xe2,0x6a,0x0f,
	0x1f,0x38,0xb0,0xac,0x2e,0xe1,0x37,0x3f,0xac,0x39,0x70,0x85,0x2f,0xaf,0xf6,0x8a,
	0x5c,0x22,0x50,0x62,0xb7,0x0e,0x41,0x97,0xf8,0xc3,0x5f,0x26,0xfe,0x83,0xb0,0x56,
	0x5d,0x2b,0x08,0x5b,0x86,0xe2,0xf9,0x15,0xd5,0x17,0xbd,0x65,0x5e,0x63,0xb0,0xeb,
	0x0c,0xee,0xe8,0x2e,0x8d,0x29,0x09,0xfd,0x52,0x77,0x4e,0xd3,0x61,0xb4,0xe9,0xd2,
	0x83,0x58,0x77,0x1c,0x6d,0xf0,0x73,0x5f,0x5d,0x6e,0xe0,0xce,0x8b,0xdf,0x22,0xba,
	0x45,0x62,0xba,0x03,0xd0,0x2a,0xcc,0x96,0x50,0xc2,0xb6,0x16,0xb5,0xe5,0xe8,0x00,
	0x56,0xcb,0x87,0x69,0xc6,0x58,0xb6,0xd6,0x36,0xd3,0x76,0xac,0xb3,0xe4,0x0f,0x26,
	0x77,0x50,0x19,0xfe,0x10,0x7f,0xe6,0x09,0x02,0x9a,0xcf,0x5b,0xa4,0xef,0x2e,0xc8,
	0x96,0x18,0x8e,0xb4,0x17,0x1d,0xe4,0x10,0x1c,0x9d,0x62,0x01,0x6c,0x47,0x39,0x69,
	0xcc,0xc5,0x8f,0x1b,0x23,0xe0,0xf8,0x13,0xc7,0xee,0x6a,0x51,0xa4,0xe9,0xa4,0x9d,
	0x86,0x2b,0x41,0x39,0x65,0xc9,0x91,0xf1,0x4e,0x56,0xb5,0x92,0xc2,0xe4,0xdf,0x1d,
	0xb8,0xf0,0x4c,0x90,0x39,0x32,0xfb,0xc1,0xe3,0x3a,0xd9,0xa6,0x39,0x18,0x2d,0xc6,
	0xc4,0x93,0x2d,0x39,0x65,0xae,0x7c,0xed,0x3b,0x5a,0x88,0x63,0xcc,0x29,0x56,0xb1,
	0x98,0x0e,0xbd,0xb8,0xb0,0xdd,0x51,0x68,0x12,0x25,0x71,0x82,0x90,0x9e,0xe6,0x58,
	0x83,0xbe,0x96,0x11,0xb9,0x56,0xc3,0x45,0x34,0xa6,0x08,0x2c,0xa1,0x7d,0xb1,0x8e,
	0x3c,0xf0,0x56,0xf2,0x50,0x8e,0x40,0xc9,0xac,0x7e,0x80,0xc9,0x85,0x01,0x4a,0x0b,
	0x9f,0x6d,0x6b,0xa9,0x6c,0x6a,0x4d,0x6c,0x8c,0x46,0x57,0x0e,0xb6,0x92,0xa9,0x78,
	0x50,0xc7,0xee,0x8b,0x1d,0x74,0xe1,0x00,0x8d,0x71,0xd7,0x58,0x21,0xe3,0xb3,0x1f,
	0xd6,0xfe,0x37,0xd9,0xc8,0x14,0xa6,0xad,0x4b,0x31,0xfd,0x22,0xa7,0x83,0x4c,0xdc,
	0xe2,0x72,0xac,0x36,0xf2,0xf1,0x96,0xa3,0x03,0xfe,0xfd,0x05,0xf2,0x1a,0x4f,0xc9,
	0xf9,0xfa,0xca,0x4c,0xdb,0x12,0xd2,0xb9,0x95,0xb4,0xac,0xb5,0x84,0x25,0xdd,0x84,
	0xdc,0x1b,0xfa,0x80,0x17,0x49,0x9c,0x3c,0x59,0xe2,0x51,0x67,0x26,0x90,0xf1,0xb4,
	0xaf,0x8f,0x53,0x4e,0x24,0xe6,0x14,0x7f,0x47,0xaa,0x3b,0x5b,0x8c,0x7c,0xbb,0x58,
	0x16,0x61,0xb5,0xad,0xb5,0x9f,0xe8,0x2c,0xad,0x2d,0x86,0x4d,0xbf,0xdf,0x69,0xb6,
	0x5a,0xd3,0xa4,0x92,0x83,0x72,0xe0,0xbf,0xa7,0x44,0xb6,0x03,0x33,0x4d,0x94,0x5f,
	0x63,0x6b,0x6f,0xc5,0xc1,0x67,0x0e,0x02,0x92,0x7c,0xa4,0xf8,0x24,0xfc,0x72,0xe5,
	0xd3,0x2b,0x3d,0xc3,0x69,0x32,0xe6,0x5c,0x31,0x17,0xc4,0x76,0x67,0xcb,0x2f,0xa2,
	0xbd,0x16,0x83,0x8d,0xab,0x5d,0x37,0x47,0xf5,0x69,0x50,0xe5,0xef,0xad,0xfe,0x91,
	0xf9,0xad,0xcc,0x5f,0x66,0xf6,0x4b,0xe3,0xcf,0x90,0xcf,0x90,0x4c,0x69,0x58,0x04,
	0x20,0x63,0xb1,0x48,0x11,0xb9,0x92,0xd7,0x78,0x36,0xc5,0xa2,0xbd,0x8f,0x5d,0x6e,
	0xba,0xed,0x47,0xdc,0x39,0x4f,0xff,0xb8,0xa8,0xc6,0xa3,0x0a,0xe6,0x92,0xa3,0xfb,
	0x9a,0x71,0xd8,0x78,0x69,0xa3,0xf4,0xc1,0x0f,0x5f,0xd7,0xc4,0xac,0x4e,0xbe,0xe2,
	0x9a,0x7d,0x5b,0xbc,0x56,0xad,0x96,0x43,0x4e,0xc9,0x46,0x6c,0xda,0xd9,0x83,0x17,
	0x5f,0x14,0xb9,0x02,0xcb,0x33,0x75,0x26,0x0f,0x53,0x9a,0x9b,0x6b,0xb9,0x44,0x75,
	0xa4,0x7c,0xdb,0x45,0xd3,0xfa,0x0e,0x6b,0x76,0x02,0x51,0xe3,0x34,0x6e,0xd6,0x86,
	0xf2,0x29,0x39,0x77,0x62,0x5c,0xe3,0xe7,0x07,0xd9,0xdc,0xb8,0xce,0xc7,0xd5,0xda,
	0xc1,0xd5,0x77,0x1d,0x96,0x72,0xf2,0x42,0x09,0x5b,0x3c,0x2b,0x19,0xb5,0x3a,0xb2,
	0xf3,0xf2,0xa8,0x1a,0x12,0x78,0xab,0xb4,0xe6,0xa8,0x1c,0x72,0x82,0x39,0x59,0x8a,
	0xad,0xa3,0x8a,0x7c,0xc6,0xe5,0x86,0x52,0xdd,0x05,0x04,0xd5,0x82,0x95,0x13,0xdb,
	0xbc,0x63,0xab,0x3d,0x2a,0x07,0xb2,0x54,0x57,0x36,0x97,0xc2,0x4a,0xac,0x60,0x2c,
	0x36,0x17,0x92,0xb7,0x20,0xd0,0x45,0x75,0x26,0x93,0x13,0xea,0xb5,0x19,0x29,0x13,
	0x6d,0xdc,0xe8,0x01,0xfc,0xd6,0x3a,0x78,0xa6,0xb4,0xa8,0x90,0xd6,0xf0,0x51,0x2a,
	0xc2,0x87,0x29,0x37,0x38,0x7b,0x66,0xcb,0xca,0x2e,0x52,0xfa,0x25,0xcd,0x55,0x76,
	0x1e,0xa6,0x70,0x05,0x98,0x69,0x74,0x4c,0xdd,0x54,0x12,0x4b,0x67,0xb1,0xf8,0x57,
	0xd3,0xfe,0x60,0x1e,0x12,0xf1,0x35,0x14,0xe9,0x39,0xcd,0x42,0x52,0x72,0x2c,0x9a,
	0x3d,0x73,0xf0,0x8c,0xc3,0x7c,0x9a,0x4b,0x6b,0xab,0x63,0x1f,0x46,0x53,0xb9,0x39,
	0x40,0x0d,0x30,0x3a,0xff,0x63,0x93,0x47,0xb3,0x15,0x39,0xaf,0x83,0xd5,0x54,0x55,
	0x5f,0xe1,0x0c,0x21,0x0d,0x5f,0xba,0x42,0xea,0x5b,0x14,0xbf,0x31,0xba,0xb0,0xd3,
	0x23,0xfe,0xb5,0x04,0xf4,0xb3,0x9c,0xf3,0x1e,0x6a,0xcf,0xca,0x97,0x31,0x4e,0x7e,
	0x79,0x40,0x9a,0xd6,0x8f,0xce,0xd4,0xc3,0x5b,0x1d,0xbb,0x99,0x84,0xad,0x1a,0x00,
	0x22,0xf7,0x96,0x3f,0xd8,0x9e,0xbc,0xd6,0xaa,0x55,0xae,0xca,0x79,0xd9,0xc5,0x78,
	0xab,0x1e,0x14,0xb3,0xcd,0x80,0x49,0x02,0x4d,0x7d,0x64,0xcc,0x7e,0xde,0x77,0x84,
	0x7c,0x5e,0x4a,0xe3,0xd4,0x9a,0xac,0xcd,0x69,0x16,0xad,0xe7,0xa2,0x5b,0x0b,0xe3,
	0xe1,0x54,0x1b,0xa1,0xba,0xe6,0xcd,0xb5,0xf1,0x3d,0xc5,0x20,0xc5,0xa5,0x87,0x5d,
	0x8d,0x26,0x2a,0xf1,0x49,0x53,0x93,0x15,0xd8,0x1c,0xb2,0x3c,0x4b,0x2e,0xc0,0xf5,
	0x84,0x71,0x67,0x15,0x3d,0x20,0x26,0x79,0x0a,0x28,0x67,0x6b,0xb6,0xbc,0xd3,0x9f,
	0xb0,0x7e,0x18,0xed,0x10,0xa8,0x17,0x3f,0xfa,0x65,0xd9,0xca,0x6c,0xa0,0x95,0x4f,
	0xea,0x2a,0xcd,0xdd,0x08,0xba,0x14,0x4d,0x1c,0x3a,0x35,0x1d,0xa2,0xca,0xab,0x47,
	0x6c,0xab,0xe4,0x4a,0x5f,0x13,0x29,0x6a,0xac,0x8e,0x7d,0x04,0x15,0x63,0x69,0xf2,
	0x93,0x11,0xa4,0xd4,0xe4,0x25,0x8a,0xe7,0xe9,0x3c,0x76,0x4d,0x7c,0x34,0x27,0x11,
	0xf6,0xbf,0x03,0x8a,0x06,0x7e,0xc5,0x96,0x29,0x72,0xb1,0xd7,0x7e,0xfa,0xe0,0xc1,
	0x43,0x1b,0xce,0xfc,0xba,0x3a,0xd0,0xbc,0xc3,0x26,0xc0,0x47,0x72,0x4b,0x65,0xe0,
	0xea,0xe4,0x2b,0x02,0xfd,0xf5,0xeb,0xba,0xff,0xb8,0x13,0x4d,0x12,0x27,0x8b,0x38,
	0x90,0xde,0x44,0x65,0x11,0x66,0x33,0x58,0x48,0x6f,0xea,0x09,0x3c,0x57,0x79,0xb6,
	0xf2,0xb2,0x88,0x58,0xbc,0xc4,0xac,0x0d,0x74,0xd2,0xa7,0xa3,0x6d,0x3a,0x13,0xc5,
	0x0a,0xb4,0x9a,0x49,0x9b,0xb4,0x9c,0xdb,0xcd,0x42,0x27,0x10,0x75,0xe5,0x8c,0x27,
	0x92,0xbd,0xd0,0x6c,0xdc,0x8c,0x5e,0x90,0x92,0x2e,0x59,0xe7,0x63,0xcf,0x4d,0xdd,
	0xae,0xf3,0x10,0x1b,0x79,0x6d,0xc5,0x61,0xa4,0xe2,0x8e,0x95,0x7a,0xae,0xd2,0xa3,
	0x92,0x9c,0x84,0xb6,0xbd,0x97,0x0b,0x70,0x32,0x9e,0x8d,0x27,0xf8,0xca,0xb2,0x12,
	0x2f,0x0b,0x04,0xa4,0xb9,0x58,0x58,0x65,0xef,0x64,0x09,0x4c,0x39,0x85,0xc2,0x39,
	0xd9,0x30,0xe7,0x46,0x6d,0x9b,0xe9,0x83,0x6d,0x67,0xa5,0xe7,0x9e,0xd2,0x9c,0xa3,
	0x85,0xa6,0x69,0xed,0x6c,0x19,0x7f,0xb4,0x5d,0x18,0x4c,0xe4,0x5a,0xd7,0x65,0xfa,
	0x8a,0xc3,0x65,0x5d,0xbc,0x49,0xf4,0xd4,0xb6,0xcb,0xef,0x3a,0x59,0x6e,0x92,0x3b,
	0x53,0xe9,0xf2,0x68,0x9c,0x97,0x73,0x51,0xb4,0x2b,0xd7,0xee,0x41,0x65,0xea,0xe0,
	0x33,0x16,0x5a,0x66,0x89,0x17,0xb2,0xf7,0x29,0x0a,0x1b,0x5c,0x61,0xbc,0xd2,0x9c,
	0x03,0xf2,0xac,0xe1,0xd3,0x3c,0xe1,0x79,0x4d,0x28,0x59,0xf0,0xe6,0x4e,0xf5,0x66,
	0x8d,0x1b,0x95,0xdc,0x5a,0xa6,0xbe,0x2b,0xb7,0x21,0x32,0xb3,0xbb,0x79,0x0b,0xea,
	0x7b,0x40,0xdb,0x65,0x0a,0xed,0x9d,0x9c,0x87,0xd4,0xf9,0x75,0xfd,0x35,0x5f,0xb2,
	0xab,0x07,0x49,0xa6,0x6e,0x6a,0x77,0xd3,0xde,0xb5,0x00,0x95,0xc5,0xf6,0x9c,0x9d,
	0xf7,0x74,0x31,0xd2,0xc7,0xad,0x5c,0x6e,0xec,0x61,0x5d,0x7f,0x32,0xfa,0x98,0xd0,
	0x74,0xd3,0x7e,0xf9,0x34,0x75,0x8d,0x70,0x09,0x18,0xfd,0xf4,0x59,0xf3,0x05,0x93,
	0x56,0xb3,0x74,0x95,0xdf,0x63,0x25,0x7e,0x32,0x86,0x3a,0xe9,0xf4,0x8a,0xd1,0xc5,
	0xca,0x16,0x0f,0x95,0x32,0x5d,0x99,0x54,0xdd,0xd6,0x83,0x76,0xbd,0xa5,0xcf,0xa7,
	0xca,0x75,0x60,0x1b,0x54,0xab,0xe7,0xf9,0xdf,0x97,0xe4,0xf5,0x1e,0x9b,0x34,0x51,
	0x8b,0xed,0xac,0x8d,0xcd,0xef,0xc7,0x22,0x93,0x44,0xb4,0xf2,0x22,0xe4,0x34,0xa6,
	0xa6,0xd6,0xf1,0x24,0xbc,0x87,0xd2,0x75,0x56,0x4e,0x57,0x30,0xf8,0x09,0x6e,0xff,
	0xc1,0x97,0x5d,0x9b,0x33,0x9d,0x36,0x93,0xea,0x24,0xb9,0x89,0xe3,0x9d,0xee,0x6f,
	0xc2,0x48,0xda,0xc7,0xbb,0x23,0xe1,0x2d,0x0d,0xb4,0x8d,0xef,0x08,0xba,0xa7,0x22,
	0xd5,0x3e,0xea,0xe4,0x39,0x4a,0x23,0xfc,0xdb,0x90,0xd9,0xf3,0xe0,0xb6,0x54,0xf8,
	0xf4,0x04,0x47,0x40,0x3d,0xb6,0xed,0x62,0x6a,0x4f,0xd4,0x99,0x4c,0xe0,0xbb,0xb9,
	0x9e,0xa6,0xd2,0xfb,0xd0,0xb5,0x09,0x03,0x33,0x5f,0x6d,0xeb,0xf5,0x84,0x8f,0x59,
	0x7b,0x76,0xdd,0x58,0xcf,0xbd,0x70,0x8a,0xd8,0x1b,0xf9,0x13,0x44,0x0f,0x17,0x95,
	0x4b,0x95,0xcb,0x87,0x14,0xf2,0xc2,0x90,0xe0,0xe0,0x68,0x02,0x1d,0x31,0xe5,0x48,
	0xa6,0xc9,0x0e,0x5e,0xbd,0x6f,0x42,0x27,0xce,0x5b,0xb9,0xb0,0xb1,0x34,0x20,0x2d,
	0x97,0xe1,0xdb,0x30,0xfb,0xf1,0x4c,0x22,0x67,0xea,0x74,0x8f,0x79,0x7c,0x24,0x62,
	0xd3,0x94,0x11,0xe7,0xda,0x78,0x29,0xbb,0x69,0xee,0x3d,0x2e,0xea,0xc9,0x05,0x17,
	0xe7,0x74,0x12,0xa0,0x33,0x15,0x47,0x4e,0x37,0xc1,0x8e,0x89,0xce,0x7d,0xfd,0x71,
	0xfb,0x08,0x92,0x66,0x7c,0x94,0xcf,0xe4,0x18,0x1d,0x0b,0x19,0xf9,0x58,0x29,0xd2,
	0x47,0x65,0x3d,0x71,0x6c,0x53,0x6f,0x16,0x7e,0x3c,0x4d,0x92,0x66,0x98,0x1d,0xf3,
	0x77,0xdd,0x25,0x8b,0xe3,0x7c,0x2f,0x72,0xc2,0x86,0xd3,0x4a,0x97,0x3e,0xbc,0xc4,
	0x0c,0x9f,0x57,0x58,0xfd,0x88,0xc6,0x89,0xb0,0x8d,0x7c,0x32,0xb7,0xba,0x36,0xb1,
	0x32,0x79,0xa5,0x44,0x22,0xe7,0xb8,0xe8,0xc1,0x93,0x70,0x25,0x45,0xb6,0x7b,0xca,
	0xbf,0x2c,0x8e,0x60,0xd8,0x25,0x5d,0x9e,0xe4,0x4a,0x94,0x8e,0xda,0x34,0xd6,0x2c,
	0x9b,0x26,0x35,0xcb,0x47,0x8b,0x99,0x52,0xe5,0x72,0x5b,0xa3,0x61,0x54,0xe7,0xb7,
	0x9b,0xdf,0x75,0xf9,0x33,0xc2,0x34,0x31,0xe7,0x8a,0xca,0x72,0x72,0x68,0xdb,0xf9,
	0xba,0x0d,0xe6,0xd8,0x19,0xd7,0xf2,0x25,0x05,0xc6,0x14,0xdf,0x30,0x4e,0x4a,0xf3,
	0x67,0x95,0x9f,0xde,0xb3,0x00,0xe2,0xe6,0x2b,0x1f,0x39,0xf8,0x27,0xcb,0x5f,0x17,
	0x8b,0x87,0xc6,0xa2,0x89,0xbc,0xa3,0x04,0x1a,0x9b,0xe7,0xe4,0x56,0x7e,0xbf,0xf9,
	0xfb,0xc5,0xd9,0x53,0x68,0x81,0xcf,0xa1,0x5c,0x1e,0x81,0x1a,0x95,0x93,0x0b,0x13,
	0xaf,0x17,0xf6,0x93,0x47,0x89,0xcb,0x3d,0x4b,0x74,0xb3,0x77,0x33,0x7f,0xb2,0xf6,
	0xc8,0x44,0x11,0xe4,0x66,0xf8,0x23,0xa5,0x0d,0x48,0x5e,0x92,0x56,0x92,0x8a,0x1b,
	0x7a,0x3c,0x43,0xdd,0x24,0xed,0x26,0xc8,0x22,0x4d,0xa4,0x95,0xb1,0x7c,0xc5,0xea,
	0x0c,0x77,0xa7,0x18,0x96,0x21,0xe0,0x9f,0x38,0x7f,0xcc,0x39,0x3d,0x23,0xd9,0x96,
	0xfe,0x81,0xf1,0xcc,0xa8,0xed,0xd6,0xe3,0x70,0x6e,0x91,0xd4,0x1e,0x9b,0x27,0xf1,
	0x2f,0x55,0x88,0xcf,0x1f,0x6c,0xcb,0x66,0xfa,0x9e,0x5f,0xf4,0x90,0x68,0xdd,0x35,
	0x40,0x2f,0x5f,0xf2,0x2c,0xc8,0xa7,0x52,0x4e,0x43,0xef,0x1b,0xa8,0xd3,0xda,0xe1,
	0xec,0x7d,0xc2,0xb7,0x14,0x1c,0xaf,0x13,0xf9,0x84,0x11,0x8f,0x66,0x6e,0x9d,0xed,
	0x29,0x8a,0xcf,0x41,0x9c,0xd4,0xe6,0x23,0x58,0x57,0xe1,0x72,0xf1,0xd6,0x51,0x3f,
	0xd8,0xac,0x42,0xfb,0xac,0xbd,0xb5,0x0f,0x56,0xf5,0x56,0xeb,0x94,0x20,0xb4,0x94,
	0xea,0xe8,0x52,0xca,0x4f,0xf8,0x9d,0xdd,0xf5,0x4a,0x70,0x93,0xdf,0x59,0x7f,0x02,
	0x4e,0x4f,0x20,0x57,0x41,0x52,0x52,0x41,0x4e,0x54,0xd9,0x75,0x43,0x1f,0xc3,0x87,
	0x50,0xd1,0x50,0x50,0xd5,0x54,0x11,0x08,0x15,0x52,0x11,0x08,0x94,0xd4,0xd3,0x91,
	0x54,0x50,0x13,0x48,0xd2,0x34,0x16,0x2d,0x88,0x40,0x8c,0xa4,0x8a,0x8a,0x40,0x9e,
	0x8c,0x40,0x86,0x90,0x82,0xa4,0x8e,0x8a,0x58,0xc9,0xc8,0x26,0x55,0x4c,0x52,0x76,
	0x66,0xb1,0x93,0xd9,0x72,0x8f,0xec,0xd3,0x66,0x7b,0xae,0x43,0x5b,0x11,0x16,0x55,
	0x91,0x13,0x15,0x08,0xf4,0x48,0x2d,0x92,0xa8,0xa8,0x87,0xcb,0x26,0x94,0x05,0x12,
	0x04,0x05,0x3d,0x56,0xb6,0x20,0x21,0xa6,0x22,0x10,0xa6,0xa0,0xeb,0x81,0xab,0x15,
	0x61,0x0d,0x15,0x41,0x51,0x81,0x5c,0x21,0x15,0x39,0x29,0x3c,0xd3,0x9b,0xed,0x2a,
	0x79,0x88,0x6c,0x53,0x54,0xc1,0x94,0x6a,0x4b,0x72,0x02,0xb9,0x92,0x9e,0xaf,0x85,
	0xd3,0x71,0x5d,0xda,0x49,0x6d,0x21,0x95,0x74,0x84,0x44,0x05,0x82,0xf4,0xc4,0x44,
	0x54,0x24,0x5d,0x55,0x8b,0xd7,0x29,0xb4,0x57,0xb3,0x0d,0x04,0x2a,0x48,0x8a,0x2a,
	0xa9,0x68,0x4a,0x71,0x18,0x6d,0x56,0x49,0xc4,0x5e,0x64,0x13,0x09,0x9a,0x1e,0x3a,
	0x9b,0x08,0xc8,0x55,0x12,0x15,0xd2,0x53,0xf5,0x18,0xdb,0x8f,0xcf,0x4e,0x63,0xb6,
	0x20,0xa7,0x2c,0x90,0xa5,0x24,0x27,0x22,0x16,0x90,0xe2,0x89,0xb9,0x4f,0xc2,0xad,
	0x08,0x0b,0x4a,0xaa,0x68,0x7a,0xb6,0x6c,0x8a,0x33,0x70,0x4b,0x6a,0x1e,0x59,0x5b,
	0xf1,0x2c,0xdd,0x92,0x9c,0x86,0x98,0xaa,0x88,0xcb,0x6d,0x39,0x79,0xcb,0xb9,0xb3,
	0x51,0x4f,0x95,0x7d,0x4c,0xed,0xb3,0x6d,0xa3,0x7a,0xae,0x36,0x3b,0x86,0xdd,0xf1,
	0xe6,0x3e,0x10,0xf7,0x01,0xba,0x29,0x34,0x15,0x49,0xcf,0x99,0xcd,0x89,0x2a,0x48,
	0x28,0x89,0x29,0x79,0x7c,0xee,0x04,0xb8,0x30,0x4a,0xa2,0x72,0x9e,0xac,0x7b,0x95,
	0x2d,0x82,0x6d,0xe1,0x36,0x54,0xc5,0x14,0x3c,0x0a,0xb7,0x2a,0x29,0xa8,0xa7,0xa9,
	0x62,0xd2,0x30,0x53,0xa6,0x7d,0x36,0xef,0x23,0x67,0x93,0x4a,0x9a,0x5a,0x02,0x09,
	0x9a,0x52,0xbc,0x4a,0x5b,0x54,0x55,0x70,0xbe,0xde,0x67,0xd4,0x3e,0xc0,0xb7,0xa6,
	0x20,0xa7,0xe1,0x12,0xb3,0xff,0x91,0x9d,0x60,0x6e,0x20,0x59,0x4f,0xd5,0x14,0x1f,
	0x9f,0x99,0x1b,0xf3,0x10,0xde,0x90,0x8a,0x69,0xe2,0x5e,0x17,0x78,0xa2,0xb8,0x15,
	0x81,0x10,0x15,0x19,0x15,0x0d,0x51,0x25,0x59,0x0f,0x9b,0x7d,0x48,0xf0,0xa3,0x7e,
	0x9b,0xaa,0x6a,0x36,0x8d,0xdb,0xd0,0xd3,0x14,0x75,0x01,0xdd,0x98,0x98,0x40,0x9c,
	0x8a,0x86,0x87,0xf7,0x16,0x24,0x95,0x05,0x32,0x55,0x24,0x65,0x95,0x34,0x4c,0x71,
	0x37,0x05,0xa9,0x22,0xa8,0xa0,0xe4,0x21,0xb8,0x13,0xda,0x42,0x4a,0x9a,0x8c,0x70,
	0x4f,0xce,0x66,0x43,0x1f,0xe0,0xe8,0x78,0xdb,0x07,0xcf,0x56,0x64,0x4d,0x9f,0xb6,
	0x2a,0x27,0x66,0xe2,0xbd,0x49,0x15,0x45,0x55,0x8f,0xf8,0xfd,0x57,0xed,0xa4,0x6b,
	0x27,0x42,0x5c,0xd0,0xf1,0x80,0xd9,0x89,0xf0,0xbe,0xdd,0x36,0x85,0xab,0xe4,0x31,
	0xc3,0x13,0xd1,0xfd,0xdb,0x6d,0x52,0xac,0x85,0x8c,0x9f,0x73,0xbc,0x1a,0xdc,0xb2,
	0xe7,0xd8,0xf6,0x3c,0xb3,0x80,0x6c,0x1b,0x5c,0xd6,0xfe,0x7d,0x04,0xee,0xd3,0x87,
	0xcf,0xb9,0xa5,0x6b,0xdc,0x27,0xe5,0xae,0xa3,0xb6,0x20,0xe1,0xf9,0xc1,0x0f,0xdd,
	0x7d,0x86,0x71,0xc9,0x05,0x8c,0x9f,0x69,0x3c,0x39,0xe1,0x09,0xf8,0x46,0x14,0xd4,
	0x14,0x74,0x54,0x34,0xc5,0xa2,0x98,0x6b,0xf7,0xf2,0xc7,0xdf,0xcd,0x72,0x3e,0x01,
	0x50,0x45,0x43,0xc9,0x34,0x98,0x1f,0xb8,0xfc,0x60,0xdc,0x47,0xf5,0xc6,0x6c,0x84,
	0xf8,0xd1,0xb2,0x45,0x55,0xd3,0xf7,0x7d,0x30,0xf3,0x77,0x96,0x03,0x09,0x1e,0xf3,
	0x3b,0x75,0xe3,0x89,0xe6,0x7e,0x0d,0x78,0x1a,0xb2,0xd3,0xd7,0xcd,0x19,0x59,0xef,
	0xc3,0x95,0xff,0x21,0x1b,0x08,0xaa,0xc2,0xe5,0xdf,0xee,0x4e,0xed,0x37,0xa6,0xe7,
	0x59,0xc5,0x0f,0x70,0x8e,0x28,0x88,0x2a,0x98,0x94,0xf3,0x15,0xa1,0x13,0x2a,0x26,
	0xf9,0x9c,0x54,0x91,0xf3,0xdc,0xe3,0x6b,0xdb,0x16,0x34,0x34,0x54,0x25,0x3d,0xd9,
	0x76,0xaa,0xd0,0x53,0x82,0x7e,0x62,0x73,0x53,0xd5,0x73,0x6d,0x4b,0x72,0x2e,0x5a,
	0x9c,0x22,0x7d,0xe5,0xab,0xd0,0x96,0x24,0x3d,0xff,0x77,0x6b,0xb8,0xd7,0x3e,0x0e,
	0xc4,0x28,0x28,0x89,0xa9,0x7a,0xc6,0xef,0xdf,0x80,0x1f,0x03,0xdd,0xf3,0x04,0xe5,
	0x89,0x46,0x5f,0x1f,0xf8,0xfc,0xc7,0x23,0x0d,0x6e,0x7a,0xc8,0xce,0x14,0x8a,0x03,
	0x49,0x32,0x9e,0x20,0xdd,0x10,0xf2,0xcd,0xe3,0x69,0x4c,0xcf,0x03,0x39,0xe4,0xf1,
	0xc9,0x09,0x15,0xcf,0xa9,0x2e,0x88,0xc8,0x7a,0xa6,0x6d,0xc4,0x07,0xa7,0x53,0x1c,
	0xea,0xdb,0x54,0xf2,0x45,0xe7,0x27,0x5b,0x5f,0xad,0xfa,0x63,0xcd,0x97,0x88,0xbd,
	0x16,0x81,0x53,0xa2,0x2f,0x6c,0xfd,0x4b,0x2d,0x29,0x6c,0xa1,0x58,0xff,0xfa,0x59,
	0x2b,0x53,0x4a,0x2d,0xb8,0x48,0xd9,0x56,0x5d,0xa2,0x2e,0x9e,0xf9,0xa8,0xec,0x27,
	0x0d,0x25,0x07,0xe2,0x3c,0x5d,0xf2,0x3b,0xa3,0xcd,0xd3,0x24,0xfe,0x7e,0x68,0xe4,
	0x83,0x40,0x63,0x7b,0x83,0x1f,0xe5,0xf9,0x71,0xc9,0xf5,0x45,0xba,0xa3,0xc4,0x33,
	0x9f,0x1e,0x18,0x7d,0x00,0xd3,0x84,0x13,0x1f,0xe5,0xc1,0xfb,0x64,0xd3,0x4b,0x84,
	0x6d,0x9f,0x66,0x63,0x66,0xd3,0x74,0xfc,0x8e,0xd8,0xd4,0xf8,0xa6,0xbb,0x75,0xd1,
	0x94,0xd0,0x69,0xed,0x6d,0xdb,0x72,0xa3,0x67,0x16,0x56,0x7d,0xc4,0x89,0x8e,0x5d,
	0x37,0x77,0x7a,0x3e,0x21,0x89,0xed,0xda,0x2a,0xe7,0x7d,0x10,0x26,0x7d,0x17,0xd3,
	0xcf,0x48,0x52,0xc4,0x52,0x13,0xfd,0xf8,0x41,0x8d,0x69,0xac,0x2d,0xf3,0x5c,0x84,
	0x62,0x88,0xdc,0xbc,0xd7,0x53,0xb5,0xaf,0xb1,0xd7,0x5c,0x98,0x39,0x5d,0xee,0x89,
	0x78,0x9f,0x3c,0xfc,0x12,0x21,0xd6,0x7d,0x9d,0x6a,0xa9,0x35,0x23,0x26,0x3e,0xfe,
	0xf1,0x8c,0xa9,0x11,0x9c,0x82,0x42,0xb3,0x51,0x1a,0x22,0x75,0x36,0x69,0xf6,0x93,
	0x9c,0xb6,0x09,0xf1,0x30,0xc4,0x4d,0x6c,0xce,0x6b,0xd0,0xfa,0xc8,0x92,0x25,0xbf,
	0x42,0xf9,0xb3,0x71,0x24,0xd4,0x75,0x69,0xcc,0xd1,0xa1,0x5b,0x3c,0x31,0xd1,0xbc,
	0xa7,0x89,0x0e,0x50,0x7c,0xf8,0xf7,0x36,0xf0,0x82,0x7b,0x2f,0x0e,0x78,0x71,0x66,
	0x8b,0xac,0x5a,0x42,0x7c,0x4a,0x28,0xdf,0x55,0x95,0x08,0x91,0x04,0x54,0x3f,0x23,
	0x0a,0x2f,0xed,0xef,0xeb,0xa1,0x8f,0x28,0xdd,0xdd,0xe2,0x8f,0xac,0xc2,0x9d,0x9e,
	0xc5,0x46,0xd1,0x1f,0x7b,0x4d,0xf9,0x40,0x59,0xc8,0xca,0xc2,0x0d,0x27,0x4b,0x62,
	0xef,0x51,0x86,0x93,0xdf,0xc3,0xb7,0x8a,0xfa,0x1e,0x04,0xe0,0xa5,0x90,0x8e,0xef,
	0x20,0xf5,0x4b,0xad,0x4f,0xbe,0xf5,0x1a,0xa6,0xf9,0x1a,0x51,0xbf,0x5c,0xde,0x0b,
	0x99,0x6c,0xf1,0xdd,0x6e,0x32,0x14,0x7b,0x80,0x6f,0xfa,0x72,0x4d,0x3f,0x1a,0x33,
	0x75,0x62,0xab,0x5f,0xdf,0x45,0xe1,0xf8,0x1b,0x07,0x19,0x4e,0x38,0xc5,0xfd,0x75,
	0xa0,0x67,0xaa,0xf5,0x63,0xea,0x0b,0x54,0xd7,0x98,0xa6,0xb5,0x00,0xb1,0xc3,0x9f,
	0xe4,0xf3,0x31,0xa6,0x13,0x94,0x0f,0xd5,0xfb,0xa2,0x84,0x5a,0xfd,0xb7,0xf9,0x0d,
	0xf5,0x5f,0xb8,0xdf,0x4d,0xe1,0xd3,0x8a,0xa1,0xd3,0xc5,0xd6,0x7a,0xc2,0x04,0xe7,
	0x35,0xc1,0xfa,0x90,0xee,0xe7,0xa5,0xc7,0x6a,0xd9,0xdc,0xc9,0x91,0x23,0xcc,0x9d,
	0x20,0xf5,0x88,0x73,0x9f,0xa4,0xfa,0xa1,0x36,0x8f,0x60,0x5c,0x55,0xe9,0x91,0x97,
	0x4f,0x0b,0x19,0xe1,0xaa,0xc3,0x3d,0xa7,0x81,0xff,0x93,0xde,0xc9,0x6c,0xfe,0xb8,
	0xf7,0x3f,0xbe,0x97,0xf5,0x6d,0x7a,0xb4,0xfc,0x84,0x02,0xcf,0x97,0xe5,0xab,0xf8,
	0x31,0x3b,0x5e,0xfd,0xfd,0x8a,0x1f,0x12,0x93,0xdc,0x56,0xf8,0x16,0x80,0x66,0x75,
	0xbe,0x2e,0x7a,0xdb,0xb6,0xfb,0x8c,0xff,0xdd,0xfc,0x9f,0xb9,0x77,0x8b,0xc6,0x5a,
	0xec,0x1f,0x49,0x97,0x39,0xcd,0xf4,0x5f,0xa4,0xee,0x1e,0x74,0xd2,0xfd,0x3f,0x1a,
	0xc0,0x85,0xf5,0x1f,0x81,0xef,0x09,0xfc,0x56,0x20,0xf3,0x02,0x87,0xbf,0x49,0xe2,
	0x5b,0xa2,0x83,0xf3,0x9e,0x97,0xc4,0xda,0x76,0xb2,0x2f,0x2d,0xb0,0x5d,0x1d,0xc9,
	0xb1,0x56,0x4e,0x1a,0x1a,0xb9,0x37,0xf7,0xa9,0xff,0xdb,0x30,0x72,0xa8,0xe9,0x93,
	0xbd,0x4b,0xa7,0x69,0xe5,0xad,0xce,0x17,0xd9,0xbf,0x55,0xd6,0x99,0x1f,0xdb,0xf6,
	0x1e,0x65,0x9d,0xc3,0xac,0x1d,0xdc,0x7e,0x12,0x55,0xd8,0xd2,0x8b,0xe9,0x3d,0xc6,
	0xed,0x4a,0xc1,0x0e,0xbc,0xbf,0x18,0xf9,0xc4,0xf3,0xa6,0x3b,0x38,0x57,0x59,0x07,
	0xc0,0x57,0x7e,0xfd,0x9b,0x23,0xf7,0x79,0xaf,0x0f,0x6a,0x9c,0xfa,0xfc,0x98,0xe7,
	0xb3,0x1d,0x29,0xa0,0x5b,0xf6,0xa9,0xb4,0x6f,0x69,0xfd,0x94,0xed,0xdb,0xe1,0xcf,
	0x7d,0xde,0xeb,0x83,0x1a,0xb7,0x4b,0xfa,0x50,0xd5,0x0d,0x69,0x14,0x24,0x34,0xf5,
	0xc4,0x3c,0x2e,0x39,0xa6,0x6c,0xbe,0xb3,0xed,0x96,0xe9,0xff,0x60,0x7f,0x20,0x74,
	0xf9,0x83,0xee,0x03,0xaf,0x8d,0xc3,0xdd,0xa9,0xdd,0x01,0x6b,0xd8,0xff,0xcf,0xfd,
	0x5b,0xc8,0x56,0xf7,0x96,0xda,0x77,0x65,0xec,0xf3,0x88,0x2e,0xa9,0xfe,0xa7,0xf7,
	0xeb,0xff,0x7f,0xda,0xcc,0x3c,0x7f,0x63,0x27,0x7d,0xac,0x5a,0xf9,0x83,0xee,0x03,
	0xaf,0x8d,0xc3,0xd8,0x69,0x99,0xfe,0x15,0xf6,0x4f,0x7d,0x31,0xb4,0x3c,0x78,0xa2,
	0xa3,0xd7,0xde,0x59,0xed,0x28,0xe0,0xb5,0x71,0xb8,0x3b,0x2d,0xb7,0x1e,0x78,0x6d,
	0x1c,0xc6,0x4e,0x31,0xf8,0x8f,0x1b,0xc7,0xee,0x81,0xb6,0x16,0xfd,0xd3,0xff,0xaa,
	0x9f,0x7a,0x32,0xaf,0xb8,0xf4,0x0d,0xa7,0xd5,0x8e,0x5a,0xa7,0xe4,0x21,0xfd,0x4f,
	0xfc,0x9c,0x14,0xe4,0xd4,0x77,0xae,0x71,0xf2,0x40,0xd5,0x2b,0x53,0xbe,0x09,0x0e,
	0xf0,0xda,0x38,0xdc,0x9d,0x96,0x5b,0x0f,0xbc,0x36,0x0e,0x63,0xa7,0xa7,0xe5,0xb4,
	0xbf,0x75,0xa5,0xfc,0x27,0xbc,0xd3,0x3e,0x0e,0xae,0xb2,0x96,0xf1,0xa1,0xff,0x8f,
	0xc1,0x99,0x50,0x7f,0x65,0xee,0x73,0x67,0x9e,0x7f,0xd7,0x5c,0x4b,0x2b,0x0d,0xf6,
	0x0b,0x81,0x36,0x3f,0xa2,0xc0,0x32,0x2c,0xe7,0xdd,0xf0,0x58,0xa2,0x27,0xfc,0xaf,
	0xf0,0x2d,0xe1,0x1b,0xcb,0xd3,0x4f,0x94,0x80,0xb7,0xfc,0x91,0xf5,0xa1,0x22,0x28,
	0x31,0x1f,0xae,0x87,0xec,0x1f,0x81,0xef,0xc8,0x86,0xcb,0xf3,0x20,0xa7,0x30,0x4f,
	0xf5,0xf3,0x31,0x0d,0x53,0xb5,0xca,0xdd,0xf0,0xa9,0xf4,0x55,0xa6,0x45,0xa6,0xd6,
	0xc0,0xf5,0x0b,0x22,0xaa,0x43,0x51,0x6c,0xdb,0xa5,0x99,0x29,0xb8,0x93,0x36,0x61,
	0xde,0xb0,0x94,0x24,0xd8,0xb4,0x33,0xec,0x38,0x8b,0x67,0xbf,0x3d,0xda,0x7c,0xca,
	0xf6,0x16,0xf8,0x9f,0x5a,0xfb,0xe6,0x2b,0xc9,0x7a,0xcb,0x1f,0xb1,0x98,0xfb,0x40,
	0xfa,0x89,0x0e,0xc0,0x5a,0x60,0xe8,0x79,0xac,0xe3,0x17,0xd4,0x62,0xc0,0x5a,0x03,
	0x2f,0x8e,0x3e,0xf1,0xee,0xef,0xdb,0x7f,0xc8,0xfe,0xf9,0xff,0x81,0x1d,0xb9,0xcf,
	0x7b,0x7d,0x50,0xe3,0x74,0x2a,0xa4,0xb2,0x74,0x61,0x71,0x67,0x7b,0x4f,0x50,0xd8,
	0x71,0x6f,0x0e,0x29,0xdd,0xe8,0xc3,0xb4,0x19,0x9a,0x1f,0xbd,0xf0,0x4d,0xc5,0xe7,
	0xb1,0xa6,0x3c,0xae,0xbd,0x39,0x10,0xa4,0xb0,0xf1,0x09,0x0d,0xd7,0xed,0x8f,0xd7,
	0xfa,0xc4,0x54,0x6d,0x1c,0xef,0x1f,0x55,0xfe,0x54,0xf6,0xde,0xdc,0x7c,0x67,0x0a,
	0x38,0x2c,0xfb,0xa9,0xf1,0x96,0x13,0x90,0x5c,0x78,0xf9,0x53,0xd9,0x27,0x90,0xfa,
	0x24,0x05,0x29,0xf0,0x6a,0x63,0x19,0xeb,0xc9,0xff,0x1f,0xcb,0xfb,0xd3,0xff,0xf8,
	0xf9,0x4f,0xdd,0xf9,0xcd,0xab,0xd5,0x89,0x4e,0x4c,0x7c,0xa6,0x1b,0x96,0x1b,0x9d,
	0xfc,0xe8,0x38,0xa5,0x4c,0x78,0x62,0x06,0xa8,0xb5,0x58,0x58,0x68,0xd8,0xd9,0x3e,
	0x8f,0xd4,0x9b,0xe4,0xd4,0xe3,0xd4,0x2f,0x9c,0x61,0xae,0xcf,0xab,0x00,0x4a,0x82,
	0xd7,0x32,0x60,0x12,0xeb,0xdf,0xf6,0xfd,0x45,0x93,0x36,0x7a,0xf5,0x3c,0xf5,0xab,
	0xfc,0xbb,0x50,0x4a,0xbe,0x73,0x23,0xd9,0x71,0x0a,0x7f,0xec,0x76,0x33,0x44,0xd4,
	0xb9,0x45,0xef,0x6b,0xb0,0x9f,0x79,0xfb,0x12,0x35,0x0f,0x7a,0xf8,0xba,0xb3,0x2f,
	0x33,0x24,0xf6,0x9f,0xe2,0x63,0xfe,0xaf,0x6a,0xf8,0xd8,0xf2,0xa1,0x8b,0x01};
#define	GETBITS(x,buf,idx,bits)	\
x=0;	\
for (j=0;j<bits;j++)	\
{	\
	x|=((((buf[idx/8])>>(idx%8))&1)<<j);	\
	(idx)++;	\
}

	unsigned char gplbuf[17999];
	int i,j;
	int idx=0;
	int widx=0;
	char		ptrnotcodebook;
	unsigned char	len;
	unsigned char	character;
	unsigned short	ptr;
	unsigned char	ptrlen;
	int		newlinecnt=0;
	ptrlen=0;
	while (idx<packbits)
	{	
		GETBITS(ptrnotcodebook,packedgpl,idx,1);	// get 1 bit from packedgpl
		if (!ptrnotcodebook)	// =0: a character
		{
			GETBITS(character,packedgpl,idx,7);	// the character is packed in the next 7 bits
			gplbuf[widx++]=character;
		} else {		// =1: a pointer to a portion which was unpacked before
			GETBITS(len,packedgpl,idx,4);		// 4 bits of the len
			GETBITS(ptr,packedgpl,idx,ptrlen);		// get ptrlen bits

			for (j=0;j<len;j++)	gplbuf[widx++]=gplbuf[ptr+j];
		} 
		while (widx>(1<<ptrlen)) ptrlen++;
		if (ptrlen>14) ptrlen=14;
	}
#undef	GETBITS
	for (i=0;i<widx;i++)
	{
		printf("%c",gplbuf[i]);
		if (gplbuf[i]==10) newlinecnt++;
		if (newlinecnt>=24) 
		{
			warte();
			newlinecnt=0;
		}
	}
	printf("\n");
}
void ende()
{
fprintf(stderr,"This program is free software; you can redistribute it and/or modify\n");
fprintf(stderr,"it under the terms of the GNU General Public License as published by\n");
fprintf(stderr,"the Free Software Foundation; either version 2 of the License, or\n");
fprintf(stderr,"(at your option) any later version.\n");
fprintf(stderr,"\n");
fprintf(stderr,"This program is distributed in the hope that it will be useful,\n");
fprintf(stderr,"but WITHOUT ANY WARRANTY; without even the implied warranty of\n");
fprintf(stderr,"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n");
fprintf(stderr,"GNU General Public License for more details.\n");
fprintf(stderr,"\n");
fprintf(stderr,"You should have received a copy of the GNU General Public License\n");
fprintf(stderr,"along with this program; if not, write to the Free Software\n");
fprintf(stderr,"Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA\n");
fprintf(stderr,"\n");
}
